@@ -31,10 +31,11 @@ class Scheduler(object):
 
 class SchedulerTask(object):
 
-    def __init__(self, func,time,event_type):
+    def __init__(self, func,time,event_type,*args):
         self.__func = func
         self.__time = time
         self.__event_type = event_type
+        self.__args = args
         self.pre_execute_time = None
 
     def raise_event_on_time(self,event_bus):
@@ -45,13 +46,12 @@ class SchedulerTask(object):
         if(isinstance(self.__time,datetime.datetime)):
             if self.__time.strftime('%Y%m%d%H%M%S') == timeStr:
                 self.__raise_event(now,event_bus)
-            return
-        currTime = int(timeStr)
-        if (currTime % 1000000 == self.__time):
-            self.__raise_event(now,event_bus)
+        elif(isinstance(self.__time,datetime.time)):
+            if self.__time.strftime('%H%M%S') == now.strftime('%H%M%S'):
+                self.__raise_event(now,event_bus)
 
     def __raise_event(self,raise_time,event_bus):
-        task_event = Event(self.__event_type,func = self.__func,raise_time = raise_time)
+        task_event = Event(self.__event_type,func = self.__func,raise_time = raise_time,args = self.__args)
         event_bus.publish_event(task_event)
         self.pre_execute_time = raise_time
         logger.info('run scheduler:' + raise_time.strftime('%Y%m%d%H%M%S'))
\ No newline at end of file
