@@ -132,10 +132,16 @@ class StrategyContext(object):
         """
         if quantity == 0:
             return None
-        posList = self.get_position(symbol)
-        if posList is None or posList.count <= 0:
+        all_pos = self.get_positions()
+        if not all_pos:
+             return None
+        posList = []
+        for x in all_pos:
+            if x.symbol == symbol:
+                posList.append(x)
+        if posList is None or len(posList) <= 0:
             return None
-        if posList.count >= 2:
+        if len(posList) >= 2:
             raise Exception('smart order only support one way position!')
         pos = posList[0]
         if pos.side == PosSide.Net:
@@ -208,7 +214,7 @@ class StrategyContext(object):
         return data
 
     def get_position(self, symbol):
-        """获取订阅列表"""
+        """获取持仓"""
         all_pos = self.get_positions()
         if not all_pos:
             return all_pos
