@@ -20,7 +20,7 @@ class EventBus(object):
                 event = self.__eventQueue.get()  
                 self.__event_process(event)
             except Exception as e:
-                logger.error(e)
+                logger.error('event bus execute exception',e)
 
     def __event_process(self, event):
         """处理事件"""
