@@ -12,13 +12,13 @@ from urllib.parse import quote
 import os
 import string
 from iqsopenapi.environment import *
+import platform
 
 class RealTradeApiCore:
     """期货交易接口"""
 
     def __init__(self):
-        dir = os.path.join(os.path.dirname(__file__), 'Supervision')
-        self.__supervision_helper = SupervisionHelper(dir)
+        self.__supervision_helper = SupervisionHelper()
         self.__passwordKey = 'password'
         self.__tradeTokenKey = 'tradeToken'
         
